local revision = tonumber(string.sub("$Revision: 30 $", 12, -3))
local rss = _G.RShamanStat
if rss.revision < revision then rss.revision = revision end

local playerState = 
{
	ascendance = nil,
	ascendanceAura = false;
	ancestralGuidance = nil,
	guidanceAura = false;
	tidalWaves = nil,
	healingBonus = 0,
	damageBonus = { [1] = 0.0, [2] = 0.0, [3] = 0.0, [4] = 0.0, [5] = 0.0, [6] = 0.0, [7] = 0.0 },
	masteryBonus = 0.0,
	criticalChance = { [1] = 0.0, [2] = 0.0, [3] = 0.0, [4] = 0.0, [5] = 0.0, [6] = 0.0, [7] = 0.0 }
}

function rss.CreateCopyRecord()
	local record = { };
	record.rawHealing = 0.0;
	record.incrementalInt = 0.0;
	record.incrementalMastery = 0.0;
	record.incrementalCritical = { 0.0 , 0.0 };
	record.effectiveCopies = 0.0;
	return record;
end
-- deal with healing copy abilities
-- we assume that every 1% increase in our raw (not effective) heals during the duration will mean a corresponding 1% increase in the effective (not raw) copied heals
function rss.ProcessCopyRecord(record, fight)
	if fight and record.rawHealing > 0 then
		--print("Raw copiable: "..record.rawHealing);
		--print("Effective copy: "..record.effectiveCopies);
		--print("Int%%: "..(100*record.incrementalInt/record.rawHealing));
		fight.incrementalIntellect = fight.incrementalIntellect + record.effectiveCopies*(record.incrementalInt/record.rawHealing);
		record.incrementalInt = 0.0;
		fight.incrementalMastery = fight.incrementalMastery + record.effectiveCopies*(record.incrementalMastery/record.rawHealing);
		record.incrementalMastery = 0.0;
		for i = 1, 2 do
			fight.incrementalCritical[i] = fight.incrementalCritical[i] + record.effectiveCopies*(record.incrementalCritical[i]/record.rawHealing);
			record.incrementalCritical[i] = 0.0;
		end
		record.rawHealing = 0.0;
		record.effectiveCopies = 0.0;
	end
end

function rss.MonitorState(fight)
	playerState.healingBonus = GetSpellBonusHealing();
	for i = 1, 7 do
		playerState.damageBonus[i] = GetSpellBonusDamage(i);
	end
	playerState.masteryBonus = 0.03 * GetMastery();
	for i = 1, 7 do
		playerState.criticalChance[i] = GetSpellCritChance(i);
	end
	local tidalWavesUp = false;
	local ascendanceUp = false;
	local guidanceUp = false;
	for i = 1, 40 do
		local id = select(11,UnitAura("player", i));
		if id then
			if id == rss.AURA_TIDAL_WAVES then
				tidalWavesUp = true;
			elseif id == rss.AURA_ASCENDANCE then
				ascendanceUp = true;
			elseif id == rss.AURA_ANCESTRAL_GUIDANCE then
				guidanceUp = true;
			end
		else
			break;
		end
	end
	playerState.tidalWaves = tidalWavesUp;
	if ascendanceUp and not playerState.ascendanceAura then
		if playerState.ascendance then
			rss.ProcessCopyRecord(playerState.ascendance, fight);
		end
		playerState.ascendance = rss.CreateCopyRecord();
	end
	playerState.ascendanceAura = ascendanceUp;
	
	if guidanceUp and not playerState.guidanceAura then
		if playerState.ancestralGuidance then
			rss.ProcessCopyRecord(playerState.ancestralGuidance, fight);
		end
		playerState.ancestralGuidance = rss.CreateCopyRecord();
	end
	playerState.guidanceAura = guidanceUp;
	
	return playerState;
end